<?php
/**
 * Gutenberg Editor CSS
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package     Citrus
 * @author      Citrus
 * @copyright   Copyright (c) 2019, Citrus
 * @link        http://themes-demo.com/citrus/
 * @since       Citrus 1.0
 */

if ( ! class_exists( 'Gutenberg_Editor_CSS' ) ) :
	/**
	 * Admin Helper
	 */
	class Gutenberg_Editor_CSS {

		function __construct() {

			add_action('after_setup_theme', array( $this,  'citrus_after_setup_theme' ) );

			add_action( 'current_screen', array( $this,  'citrus_current_screen_hook' ), 10, 1 );
			add_action( 'enqueue_block_editor_assets', array( $this, 'citrus_backend_editor_styles' ), 10 );
			if ( class_exists( 'Classic_Editor' ) ) {
				add_filter( 'tiny_mce_before_init', array( $this, 'citrus_theme_editor_dynamic_styles' ) );
			}

			add_action( 'wp_enqueue_scripts', array( $this, 'citrus_editor_enqueue_styles'), 110 );

		}

		public function citrus_after_setup_theme() {

			# Gutenberg Compatible
			add_theme_support( 'align-wide' );
			add_theme_support( 'wp-block-styles' );
			add_theme_support( 'editor-styles' );
			
			# Add support for responsive embedded content.
			add_theme_support( 'responsive-embeds' );

			$skin = dttheme_option('appearance','skin');
			$skin = ($skin != '') ? $skin : 'green';

			$colors          = $this->citrus_skins( $skin );
			$primary_color   = $colors['primary-color'];
			$secondary_color = $colors['secondary-color'];
			$tertiary_color  = $colors['tertiary-color'];

			add_theme_support( 'editor-color-palette', array(
				array(
					'name'  => esc_html__( 'Primary Color', 'citrus' ),
					'slug'  => 'primary',
					'color' => $primary_color,
				),
				array(
					'name'  => esc_html__( 'Secondary Color', 'citrus' ),
					'slug'  => 'secondary',
					'color' => $secondary_color,
				),
				array(
					'name'  => esc_html__( 'Tertiary Color', 'citrus' ),
					'slug'  => 'tertiary',
					'color' => $tertiary_color,
				)
			));

		}

		public function citrus_skins( $skin ) {

			$skins['blue'] = array ( 'primary-color' => '#478bca', 'secondary-color' => '#1a5fa0', 'tertiary-color' => '#87b3dc' );
			$skins['blueiris'] = array ( 'primary-color' => '#595ca1', 'secondary-color' => '#35387d', 'tertiary-color' => '#8b8ff4' );
			$skins['blueturquoise'] = array ( 'primary-color' => '#08bbb7', 'secondary-color' => '#038e8a', 'tertiary-color' => '#6de6e2' );
			$skins['brown'] = array ( 'primary-color' => '#8f5a28', 'secondary-color' => '#6b421c', 'tertiary-color' => '#b78b62' );
			$skins['burntsienna'] = array ( 'primary-color' => '#d36b5e', 'secondary-color' => '#a44d42', 'tertiary-color' => '#d58a80' );
			$skins['chillipepper'] = array ( 'primary-color' => '#b31f41', 'secondary-color' => '#90112e', 'tertiary-color' => '#e27991' );
			$skins['chocolate'] = array ( 'primary-color' => '#cd671d', 'secondary-color' => '#a24e11', 'tertiary-color' => '#e0925a' );
			$skins['graasgreen'] = array ( 'primary-color' => '#81c77f', 'secondary-color' => '#4a9048', 'tertiary-color' => '#a4cba3' );
			$skins['green'] = array ( 'primary-color' => '#77be32', 'secondary-color' => '#4e8b11', 'tertiary-color' => '#a8dc74' );
			$skins['orange'] = array ( 'primary-color' => '#f39d12', 'secondary-color' => '#c17f14', 'tertiary-color' => '#f2bc64' );
			$skins['pink'] = array ( 'primary-color' => '#e67eb9', 'secondary-color' => '#c55896', 'tertiary-color' => '#ffb6e0' );
			$skins['radiantorchid'] = array ( 'primary-color' => '#af71b0', 'secondary-color' => '#824e83', 'tertiary-color' => '#da9bdc' );
			$skins['red'] = array ( 'primary-color' => '#e64d3d', 'secondary-color' => '#bf3f32', 'tertiary-color' => '#fb7a6d' );
			$skins['skyblue'] = array ( 'primary-color' => '#19a9e5', 'secondary-color' => '#158abb', 'tertiary-color' => '#67c0e6' );
			$skins['yellow'] = array ( 'primary-color' => '#eec106', 'secondary-color' => '#c9a615', 'tertiary-color' => '#e6ce69' );

			return $skins[ $skin ];
	
		}

		public function citrus_current_screen_hook( $current_screen ) {
			
			if ( 'post' == $current_screen->base ) {

				$font = $subset = '';

				$custom_fonts = array ();

				#Body Section
				$disable_boddy_settings = dttheme_option('appearance', 'disable-boddy-settings');

				if (empty($disable_boddy_settings)) :
					$font = dttheme_option('appearance', 'body-font');
					$font = str_replace(' ', '+', $font);
					if (!empty($font)) :
						array_push($custom_fonts, $font);
					endif;
				endif;

				#Typography Section
				$disable_typo = dttheme_option('appearance', 'disable-typography-settings');
				if (empty($disable_typo)) :
					for ($i = 1; $i <= 6; $i++) :
						$font = dttheme_option('appearance', 'H'.$i.'-font');
						if (!empty($font)) :
							$font = str_replace(' ', '+', $font);
							array_push($custom_fonts, $font);
						endif;
					endfor;
				endif;

				if (!empty($custom_fonts)) :
					$custom_fonts = array_unique($custom_fonts);
					$font = implode(':100,100italic,200,200italic,300,300italic,400,400italic,500,500italic,600,600italic,700,700italic,800,800italic,900,900italic|', $custom_fonts);
					$font .= ':100,100italic,200,200italic,300,300italic,400,400italic,500,500italic,600,600italic,700,700italic,800,800italic,900,900italic|';
				endif;

				$font .= 'Alegreya+Sans:400,800,700,100,500,500italic,300,800italic,900,900italic%7CSource+Sans+Pro:400,200,200italic,300,300italic,400italic,600,600italic,700,700italic,900,900italic%7CRaleway:400,100,300,200,500,600,700,800,900%7COpen+Sans:400,300,600,700,300italic%7CPacifico';

				$protocol = is_ssl() ? 'https' : 'http';
				$query_args = array('family' => $font, 'subset' => $subset);
				$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
		
				add_editor_style( $fonts_url );

				add_editor_style( 'css/editor-style.css' );

			}

		}

		public function citrus_generate_editor_styles( $editor_type = 'block' ) {
			
			if($editor_type == 'tinymce') {
				$wrapper_class = 'body#tinymce.wp-editor.content';
			} else {
				$wrapper_class = '.editor-styles-wrapper';
			}
			
			$styles = '';

			$styles .= $wrapper_class.' pre { font-family:monospace; }';

			// Body Typography
			$disable_boddy_settings = dttheme_option('appearance', 'disable-boddy-settings');
			if (empty($disable_boddy_settings)) {

				$font_type = dttheme_option('appearance', 'body-font-type');
				$style = dttheme_option('appearance','body-standard-font-style');

				if( !empty($font_type) ) {
					$body_font = dttheme_option('appearance','body-standard-font');
				} else {
					$body_font = dttheme_option('appearance', 'body-font');
				}

				$body_font_size = dttheme_option('appearance', 'body-font-size');
				$body_font_color = dttheme_option('appearance', 'body-font-color');

				$body_primary_color = dttheme_option('appearance', 'body-primary-color');
				$body_secondary_color = dttheme_option('appearance', 'body-secondary-color');

				if (!empty($body_font) || (!empty($body_font_color) and $body_font_color != '#') || !empty($body_font_size)) {

					$styles .= $wrapper_class.' > * {';
						
						if (!empty($body_font)) { 
							$styles .= 'font-family:'.$body_font.';';
						}

						if (!empty($body_font_color) && ($body_font_color != '#')) { 
							$styles .= 'color:'.$body_font_color.';'; 
						}

						if (!empty($body_font_size)) {
							$styles .= 'font-size:'.$body_font_size.'px;'; 
						}
						
						if (!empty($style)) { 
							if ($style == 'Bold Italic') {
								$styles .= 'font-weight:bold; font-style:italic;';
							} elseif ($style == 'Bold') {
								$styles .= 'font-weight:bold;';
							} elseif ($style == 'Italic') {
								$styles .= 'font-style:italic;';
							} elseif ($style == 'Normal') {
								$styles .= 'font-weight:normal; font-style:normal;';
							}				
						}

					$styles .= '}';

				}

				if (!empty($body_font_color) and $body_font_color != '#') {

					$styles .= $wrapper_class.' pre, .wp-block-pullquote {';
						$styles .= 'color:'.$body_font_color.';'; 
					$styles .= '}';

				}

				if (!empty($body_primary_color) && ($body_primary_color != '#')) {
					$styles .= $wrapper_class.' a { color:'.$body_primary_color.'; }'; 
				}

				if (!empty($body_secondary_color) && ($body_secondary_color != '#')) {
					$styles .= $wrapper_class.' a:focus, '.$wrapper_class.' a:hover { color:'.$body_secondary_color.'; }';	
				}

			} 
			// Body Typography End

			// Heading Typography
			$disable_typo = dttheme_option('appearance', 'disable-typography-settings');
			if (empty($disable_typo)) {

				for ($i = 1; $i <= 6; $i++) {

					$font_type = dttheme_option('appearance', 'H'.$i.'-font-type');
					$style = dttheme_option('appearance','H'.$i.'-standard-font-style');
					
					if( !empty($font_type) ){
						$font = dttheme_option('appearance','H'.$i.'-standard-font');
					} else {
						$font = dttheme_option('appearance', 'H'.$i.'-font');
					}
					
					$color = dttheme_option('appearance', 'H'.$i.'-font-color');
					$size = dttheme_option('appearance', 'H'.$i.'-size');

					if (!empty($font) || (!empty($color) and $color != '#') || !empty($size)) {

						if($editor_type == 'tinymce') {
							$styles .= $wrapper_class.' h'.$i.' {';
						} else {
							if($i == 1) {
								$styles .= '.editor-post-title__block .editor-post-title__input, '.$wrapper_class.' .wp-block h1 {';
							} else{
								$styles .= $wrapper_class.' .wp-block h'.$i.' {';
							}
						}

							if (!empty($font)) {
								$styles .= 'font-family:'.$font.'; ';
							}

							if( !empty($font_type) ) {
								if (!empty($style)) { 
									if ($style == 'Bold Italic') {
										$styles .= 'font-weight:bold; font-style:italic;';
									} elseif ($style == 'Bold') {
										$styles .= 'font-weight:bold;';
									} elseif ($style == 'Italic') {
										$styles .= 'font-style:italic;';
									} elseif ($style == 'Normal') {
										$styles .= 'font-weight:normal; font-style:normal;';
									}				
								}
							}

							if (!empty($color) && ($color != '#')) { 
								$styles .= 'color:'.$color.'; ';
							}
							
							if (!empty($size)) { 
								$styles .= 'font-size:'.$size.'px; '; 
							}

						$styles .= '}';

					}

				}

			}
			// Heading Typography End
			
			return $styles;

		}

		public function citrus_backend_editor_styles() {
			
			wp_enqueue_style( 'citrus-gutenberg', get_theme_file_uri('/css/admin-gutenberg.css'), false, IAMD_THEME_VERSION, 'all' );
			
			$styles = $this->citrus_generate_editor_styles('block');
			
			wp_add_inline_style( 'citrus-gutenberg', $styles );

		}
			
		public function citrus_theme_editor_dynamic_styles( $mceInit ) {

			$styles = $this->citrus_generate_editor_styles('tinymce');

			if ( isset( $mceInit['content_style'] ) ) {
				$mceInit['content_style'] .= ' ' . $styles . ' ';
			} else {
				$mceInit['content_style'] = $styles . ' ';
			}
			
			return $mceInit;
		}

		public function citrus_editor_enqueue_styles( ) {

			$styles = '';

			$primary_color = $secondary_color = $tertiary_color = '';

			$skin = dttheme_option('appearance','skin');
			$skin = ($skin != '') ? $skin : 'green';

			$colors          = $this->citrus_skins( $skin );
			$primary_color   = $colors['primary-color'];
			$secondary_color = $colors['secondary-color'];
			$tertiary_color  = $colors['tertiary-color'];

			# Primary Color
			$styles .= '.has-primary-background-color { background-color:'.$primary_color.'; }';
			$styles .= '.has-primary-color { color:'.$primary_color.'; }';
	
			# Secondary Color
			$styles .= '.has-secondary-background-color { background-color:'.$secondary_color.'; }';
			$styles .= '.has-secondary-color { color:'.$secondary_color.'; }';
	
			# Tertiary Color
			$styles .= '.has-tertiary-background-color { background-color:'.$tertiary_color.'; }';
			$styles .= '.has-tertiary-color { color:'.$tertiary_color.'; }';

			wp_add_inline_style('citrus-gutenberg', $styles );

		}

	}

	new Gutenberg_Editor_CSS();

endif;